# int_encoder/__init__.py
#
#

from . import config

####################################################################################################

def _validate_config():
    """Validates that config.INT_ENCODE_KEY and config.INT_ENCODED_MAX are properly configured."""
    if config.INT_ENCODED_MAX % config.INT_ENCODE_KEY == 0:
        raise ValueError("config.INT_ENCODE_KEY must not divide config.INT_ENCODED_MAX without a remainder.")

####################################################################################################

def encode(to_encode: int) -> int:
    """
    Encodes an integer using INT_ENCODE_KEY and INT_ENCODED_MAX.
    
    Args:
        to_encode (int): The integer to encode.
    
    Returns:
        int: The encoded integer.
    """
    _validate_config()
    int_encoded = (to_encode * config.INT_ENCODE_KEY) % config.INT_ENCODED_MAX
    return int_encoded

def decode(to_decode: int) -> int:
    """
    Decodes an encoded integer using config.INT_ENCODE_KEY and config.INT_ENCODED_MAX.
    
    Args:
        to_decode (int): The encoded integer to decode.
    
    Returns:
        int: The decoded integer.
    """
    _validate_config()
    try:
        key_inverse = pow(config.INT_ENCODE_KEY, -1, config.INT_ENCODED_MAX)
    except ValueError:
        raise ValueError("No modular inverse exists for the current values of config.INT_ENCODE_KEY and config.INT_ENCODED_MAX.")
    int_decoded = (to_decode * key_inverse) % config.INT_ENCODED_MAX
    return int_decoded
